<?php

namespace Drupal\webtexttool\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\webtexttool\Controller\WebtexttoolController;
use Drupal\Core\State\State;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure example settings for this site.
 */
class WebtexttoolSettingsForm extends FormBase {

  /**
   * The state interface.
   *
   * @var \Drupal\Core\State\StateInterface
   */
  protected $state;

  /**
   * The Webtexttool Controller.
   *
   * @var \Drupal\webtexttool\Controller\WebtexttoolController
   */
  protected $webtexttoolController;

  /**
   * Constructs the Webtexttool settings form.
   *
   * @param \Drupal\Core\State\State $state
   *   The state interface.
   * @param \Drupal\webtexttool\Controller\WebtexttoolController $webtexttoolController
   *   The webtexttool controller.
   */
  public function __construct(State $state, WebtexttoolController $webtexttoolController) {
    $this->state = $state;
    $this->webtexttoolController = $webtexttoolController;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('state'),
      $container->get('webtexttool.webtexttool_controller')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'webtexttool_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {

    $form['webtexttool_user'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Username'),
      '#default_value' => $this->state->get('webtexttool.settings.name'),
      '#description' => $this->t('The username to connect to textmetrics.com.'),
    ];

    $form['webtexttool_pass'] = [
      '#type' => 'password',
      '#title' => $this->t('Password'),
      '#default_value' => $this->state->get('webtexttool.settings.pass'),
      '#description' => $this->t('The password to connect to textmetrics.com.'),
    ];

    $form['webtexttool_language'] = [
      '#type' => 'select',
      '#title' => $this->t('Language'),
      '#options' => ['en' => $this->t('English'), 'nl' => $this->t('Dutch')],
      '#default_value' => $this->state->get('webtexttool.settings.language'),
      '#description' => $this->t('The default language of the tool itself. At this moment the tool itself is only available in Dutch and English.'),
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => 'Submit',
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    // Save the credentials in de key_value table.
    $this->state->set('webtexttool.settings.name', $form_state->getValue('webtexttool_user'));

    if ($pass = $form_state->getValue('webtexttool_pass')) {
      $this->state->set('webtexttool.settings.pass', $pass);
    }

    if ($language = $form_state->getValue('webtexttool_language')) {
      $this->state->set('webtexttool.settings.language', $language);
    }

    // Unset the webtexttool token.
    $this->webtexttoolController->webtexttoolSetToken('', FALSE);
  }

}
